PYPI_BASE_URL: str = "https://pypi.org/project/"
NPM_BASE_URL: str = "https://www.npmjs.com/package/"

HTTP_STATUS_CODE_MSG: str = "<comment>HTTP response status code: {code} ({desc})</comment>"
AVAILABLE_MSG: str = "<fg=green;options=bold>{name}</> is available!"
NOT_AVAILABLE_MSG: str = "<fg=red;options=bold>{name}</> ({url}) is not available..."
